Index: runtime/lib/stacktrace.h |
diff --git a/runtime/lib/stacktrace.h b/runtime/lib/stacktrace.h |
index e6bccae510603532ba291ed443089384bcf197ae..fe67a9dcd9723ee19b778aba3b86dc901e35a0b0 100644 |
--- a/runtime/lib/stacktrace.h |
+++ b/runtime/lib/stacktrace.h |
@@ -7,14 +7,14 @@ |
namespace dart { |
-class Stacktrace; |
+class StackTrace; |
-// Creates a Stacktrace object from the current stack. Skips the |
+// Creates a StackTrace object from the current stack. Skips the |
// first skip_frames Dart frames. |
// |
// This function is exposed to provide stack trace printing in |
// assertion failures, etc. |
-const Stacktrace& GetCurrentStacktrace(int skip_frames); |
+const StackTrace& GetCurrentStackTrace(int skip_frames); |
} // namespace dart |